pub struct PlanError { /* private fields */ }Expand description
A bounded, fail-closed plan profile error.
Implementations
Sourceimpl PlanError
impl PlanError
Sourcepub const fn code(&self) -> PlanErrorCode
pub const fn code(&self) -> PlanErrorCode
Returns the stable plan-profile error code.
Sourcepub fn field(&self) -> Option<&str>
pub fn field(&self) -> Option<&str>
Returns the annotation field associated with the failure, when available.
Sourcepub const fn operation_index(&self) -> Option<usize>
pub const fn operation_index(&self) -> Option<usize>
Returns the logical operation index associated with the failure.
Sourcepub const fn edit_index(&self) -> Option<usize>
pub const fn edit_index(&self) -> Option<usize>
Returns the edit index within the logical operation, when available.
Returns the conflicting edit index within the logical operation, when available.
Sourcepub const fn base_code(&self) -> Option<EditErrorCode>
pub const fn base_code(&self) -> Option<EditErrorCode>
Returns the underlying weavatrix-edit code for a base-plan failure.